# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Chat Service."""

__version__ = "0.4.33"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .api_add_member_params import ApiAddMemberParams
from .api_create_namespace_topic_params import ApiCreateNamespaceTopicParams
from .api_create_topic_params import ApiCreateTopicParams
from .api_create_topic_response import ApiCreateTopicResponse
from .api_muted_topic_response import ApiMutedTopicResponse
from .api_mute_user_request import ApiMuteUserRequest
from .api_send_chat_params import ApiSendChatParams
from .api_unmute_user_request import ApiUnmuteUserRequest
from .api_update_topic_params import ApiUpdateTopicParams
from .log_app_message_declaration import LogAppMessageDeclaration
from .logconfig_configuration import LogconfigConfiguration
from .logconfig_configuration import LogLevelEnum as LogconfigConfigurationLogLevelEnum
from .message_action_add_user_to_topic_result import MessageActionAddUserToTopicResult
from .message_action_delete_topic_result import MessageActionDeleteTopicResult
from .models_add_inbox_category_request import ModelsAddInboxCategoryRequest
from .models_add_inbox_category_response import ModelsAddInboxCategoryResponse
from .models_ban_topic_member_param import ModelsBanTopicMemberParam
from .models_ban_topic_member_result import ModelsBanTopicMemberResult
from .models_category_hook import ModelsCategoryHook
from .models_channel_topic_response import ModelsChannelTopicResponse
from .models_channel_topic_summary_response import ModelsChannelTopicSummaryResponse
from .models_channel_topic_with_pagination_response import (
    ModelsChannelTopicWithPaginationResponse,
)
from .models_chat_message_response import ModelsChatMessageResponse
from .models_chat_message_with_pagination_response import (
    ModelsChatMessageWithPaginationResponse,
)
from .models_chat_snapshot_message import ModelsChatSnapshotMessage
from .models_chat_snapshots import ModelsChatSnapshots
from .models_config import ModelsConfig
from .models_config_export import ModelsConfigExport
from .models_config_list import ModelsConfigList
from .models_config_response import ModelsConfigResponse
from .models_dictionary import ModelsDictionary
from .models_dictionary_child import ModelsDictionaryChild
from .models_dictionary_export import ModelsDictionaryExport
from .models_dictionary_export_item import ModelsDictionaryExportItem
from .models_dictionary_group import ModelsDictionaryGroup
from .models_dictionary_import_result import ModelsDictionaryImportResult
from .models_dictionary_insert_bulk_request import ModelsDictionaryInsertBulkRequest
from .models_dictionary_insert_request import ModelsDictionaryInsertRequest
from .models_dictionary_query_result import ModelsDictionaryQueryResult
from .models_dictionary_update_request import ModelsDictionaryUpdateRequest
from .models_dictionary_with_children import ModelsDictionaryWithChildren
from .models_dictionary_word_changes import ModelsDictionaryWordChanges
from .models_get_inbox_categories_response_item import (
    ModelsGetInboxCategoriesResponseItem,
)
from .models_get_inbox_messages_response import ModelsGetInboxMessagesResponse
from .models_get_inbox_messages_response_data import ModelsGetInboxMessagesResponseData
from .models_get_inbox_messages_response_data import (
    ScopeEnum as ModelsGetInboxMessagesResponseDataScopeEnum,
)
from .models_get_inbox_messages_response_data import (
    StatusEnum as ModelsGetInboxMessagesResponseDataStatusEnum,
)
from .models_get_inbox_stats_response import ModelsGetInboxStatsResponse
from .models_get_inbox_users_response import ModelsGetInboxUsersResponse
from .models_import_config_response import ModelsImportConfigResponse
from .models_json_schema_type import ModelsJSONSchemaType
from .models_message_request import ModelsMessageRequest
from .models_message_request import TopicTypeEnum as ModelsMessageRequestTopicTypeEnum
from .models_message_result_with_attributes import ModelsMessageResultWithAttributes
from .models_message_stats import ModelsMessageStats
from .models_pagination import ModelsPagination
from .models_public_ban_topic_members_request import ModelsPublicBanTopicMembersRequest
from .models_public_ban_topic_members_response import (
    ModelsPublicBanTopicMembersResponse,
)
from .models_public_config_response import ModelsPublicConfigResponse
from .models_public_unban_topic_members_request import (
    ModelsPublicUnbanTopicMembersRequest,
)
from .models_public_unban_topic_members_response import (
    ModelsPublicUnbanTopicMembersResponse,
)
from .models_save_inbox_message_request import ModelsSaveInboxMessageRequest
from .models_save_inbox_message_request import (
    ScopeEnum as ModelsSaveInboxMessageRequestScopeEnum,
)
from .models_save_inbox_message_request import (
    StatusEnum as ModelsSaveInboxMessageRequestStatusEnum,
)
from .models_save_inbox_message_response import ModelsSaveInboxMessageResponse
from .models_save_inbox_message_response import (
    ScopeEnum as ModelsSaveInboxMessageResponseScopeEnum,
)
from .models_save_inbox_message_response import (
    StatusEnum as ModelsSaveInboxMessageResponseStatusEnum,
)
from .models_send_inbox_message_request import ModelsSendInboxMessageRequest
from .models_send_inbox_message_response import ModelsSendInboxMessageResponse
from .models_topic_info import ModelsTopicInfo
from .models_topic_log_item import ModelsTopicLogItem
from .models_topic_log_item import TypeEnum as ModelsTopicLogItemTypeEnum
from .models_topic_log_with_pagination_response import (
    ModelsTopicLogWithPaginationResponse,
)
from .models_topic_member_response import ModelsTopicMemberResponse
from .models_topic_member_with_pagination_response import (
    ModelsTopicMemberWithPaginationResponse,
)
from .models_topic_response import ModelsTopicResponse
from .models_unban_topic_member_param import ModelsUnbanTopicMemberParam
from .models_unban_topic_member_result import ModelsUnbanTopicMemberResult
from .models_unsend_inbox_message_request import ModelsUnsendInboxMessageRequest
from .models_unsend_inbox_message_response import ModelsUnsendInboxMessageResponse
from .models_update_inbox_category_request import ModelsUpdateInboxCategoryRequest
from .models_update_inbox_message_request import ModelsUpdateInboxMessageRequest
from .models_update_inbox_message_request import (
    ScopeEnum as ModelsUpdateInboxMessageRequestScopeEnum,
)
from .models_user_inbox import ModelsUserInbox
from .response_error import ResponseError
from .restapi_error_response_body import RestapiErrorResponseBody
from .topic_info_member import TopicInfoMember



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import get_namespace as get_services_namespace
from accelbyte_py_sdk.core import run_request
from accelbyte_py_sdk.core import run_request_async
from accelbyte_py_sdk.core import same_doc_as

from ..models import ModelsAddInboxCategoryRequest
from ..models import ModelsAddInboxCategoryResponse
from ..models import ModelsGetInboxCategoriesResponseItem
from ..models import ModelsGetInboxMessagesResponse
from ..models import ModelsGetInboxStatsResponse
from ..models import ModelsGetInboxUsersResponse
from ..models import ModelsJSONSchemaType
from ..models import ModelsSaveInboxMessageRequest
from ..models import ModelsSaveInboxMessageResponse
from ..models import ModelsSendInboxMessageRequest
from ..models import ModelsSendInboxMessageResponse
from ..models import ModelsUnsendInboxMessageRequest
from ..models import ModelsUnsendInboxMessageResponse
from ..models import ModelsUpdateInboxCategoryRequest
from ..models import ModelsUpdateInboxMessageRequest
from ..models import RestapiErrorResponseBody

from ..operations.inbox import AdminAddInboxCategory
from ..operations.inbox import AdminDeleteInboxCategory
from ..operations.inbox import AdminDeleteInboxMessage
from ..operations.inbox import AdminGetCategorySchema
from ..operations.inbox import AdminGetInboxCategories
from ..operations.inbox import AdminGetInboxMessages
from ..operations.inbox import (
    AdminGetInboxMessagesScopeEnum,
    AdminGetInboxMessagesStatusEnum,
)
from ..operations.inbox import AdminGetInboxStats
from ..operations.inbox import AdminGetInboxUsers
from ..operations.inbox import (
    AdminGetInboxUsersStatusEnum,
)
from ..operations.inbox import AdminSaveInboxMessage
from ..operations.inbox import AdminSendInboxMessage
from ..operations.inbox import AdminUnsendInboxMessage
from ..operations.inbox import AdminUpdateInboxCategory
from ..operations.inbox import AdminUpdateInboxMessage
from ..models import (
    ModelsSaveInboxMessageRequestScopeEnum,
    ModelsSaveInboxMessageRequestStatusEnum,
)
from ..models import (
    ModelsSaveInboxMessageResponseScopeEnum,
    ModelsSaveInboxMessageResponseStatusEnum,
)
from ..models import ModelsUpdateInboxMessageRequestScopeEnum


@same_doc_as(AdminAddInboxCategory)
def admin_add_inbox_category(
    body: ModelsAddInboxCategoryRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """add inbox category (adminAddInboxCategory)

    Add inbox category.

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/categories

        method: POST

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsAddInboxCategoryRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsAddInboxCategoryResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminAddInboxCategory.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminAddInboxCategory)
async def admin_add_inbox_category_async(
    body: ModelsAddInboxCategoryRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """add inbox category (adminAddInboxCategory)

    Add inbox category.

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/categories

        method: POST

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsAddInboxCategoryRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsAddInboxCategoryResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminAddInboxCategory.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminDeleteInboxCategory)
def admin_delete_inbox_category(
    category: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin delete inbox category (adminDeleteInboxCategory)

    Delete inbox category

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/categories/{category}

        method: DELETE

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        category: (category) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminDeleteInboxCategory.create(
        category=category,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminDeleteInboxCategory)
async def admin_delete_inbox_category_async(
    category: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin delete inbox category (adminDeleteInboxCategory)

    Delete inbox category

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/categories/{category}

        method: DELETE

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        category: (category) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminDeleteInboxCategory.create(
        category=category,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminDeleteInboxMessage)
def admin_delete_inbox_message(
    message_id: str,
    force: Optional[bool] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin delete inbox message (adminDeleteInboxMessage)

    Delete inbox message

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/message/{messageId}

        method: DELETE

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        message_id: (messageId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        force: (force) OPTIONAL bool in query

    Responses:
        200: OK - (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminDeleteInboxMessage.create(
        message_id=message_id,
        force=force,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminDeleteInboxMessage)
async def admin_delete_inbox_message_async(
    message_id: str,
    force: Optional[bool] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin delete inbox message (adminDeleteInboxMessage)

    Delete inbox message

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/message/{messageId}

        method: DELETE

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        message_id: (messageId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        force: (force) OPTIONAL bool in query

    Responses:
        200: OK - (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminDeleteInboxMessage.create(
        message_id=message_id,
        force=force,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetCategorySchema)
def admin_get_category_schema(
    category: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get category schema (adminGetCategorySchema)

    Get category schema.

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/categories/{category}/schema.json

        method: GET

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        category: (category) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsJSONSchemaType (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetCategorySchema.create(
        category=category,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetCategorySchema)
async def admin_get_category_schema_async(
    category: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get category schema (adminGetCategorySchema)

    Get category schema.

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/categories/{category}/schema.json

        method: GET

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        category: (category) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsJSONSchemaType (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        404: Not Found - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetCategorySchema.create(
        category=category,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetInboxCategories)
def admin_get_inbox_categories(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get inbox categories (adminGetInboxCategories)

    Get inbox categories

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/categories

        method: GET

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - List[ModelsGetInboxCategoriesResponseItem] (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetInboxCategories.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetInboxCategories)
async def admin_get_inbox_categories_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get inbox categories (adminGetInboxCategories)

    Get inbox categories

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/categories

        method: GET

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - List[ModelsGetInboxCategoriesResponseItem] (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetInboxCategories.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetInboxMessages)
def admin_get_inbox_messages(
    active_only: Optional[bool] = None,
    end_created_at: Optional[int] = None,
    limit: Optional[int] = None,
    message_id: Optional[List[str]] = None,
    offset: Optional[int] = None,
    order: Optional[str] = None,
    scope: Optional[Union[str, AdminGetInboxMessagesScopeEnum]] = None,
    start_created_at: Optional[int] = None,
    status: Optional[Union[str, AdminGetInboxMessagesStatusEnum]] = None,
    transient: Optional[bool] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get inbox messages (adminGetInboxMessages)

    Get inbox messages

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/messages

        method: GET

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        active_only: (activeOnly) OPTIONAL bool in query

        end_created_at: (endCreatedAt) OPTIONAL int in query

        limit: (limit) OPTIONAL int in query

        message_id: (messageId) OPTIONAL List[str] in query

        offset: (offset) OPTIONAL int in query

        order: (order) OPTIONAL str in query

        scope: (scope) OPTIONAL Union[str, ScopeEnum] in query

        start_created_at: (startCreatedAt) OPTIONAL int in query

        status: (status) OPTIONAL Union[str, StatusEnum] in query

        transient: (transient) OPTIONAL bool in query

    Responses:
        200: OK - ModelsGetInboxMessagesResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetInboxMessages.create(
        active_only=active_only,
        end_created_at=end_created_at,
        limit=limit,
        message_id=message_id,
        offset=offset,
        order=order,
        scope=scope,
        start_created_at=start_created_at,
        status=status,
        transient=transient,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetInboxMessages)
async def admin_get_inbox_messages_async(
    active_only: Optional[bool] = None,
    end_created_at: Optional[int] = None,
    limit: Optional[int] = None,
    message_id: Optional[List[str]] = None,
    offset: Optional[int] = None,
    order: Optional[str] = None,
    scope: Optional[Union[str, AdminGetInboxMessagesScopeEnum]] = None,
    start_created_at: Optional[int] = None,
    status: Optional[Union[str, AdminGetInboxMessagesStatusEnum]] = None,
    transient: Optional[bool] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get inbox messages (adminGetInboxMessages)

    Get inbox messages

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/messages

        method: GET

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        active_only: (activeOnly) OPTIONAL bool in query

        end_created_at: (endCreatedAt) OPTIONAL int in query

        limit: (limit) OPTIONAL int in query

        message_id: (messageId) OPTIONAL List[str] in query

        offset: (offset) OPTIONAL int in query

        order: (order) OPTIONAL str in query

        scope: (scope) OPTIONAL Union[str, ScopeEnum] in query

        start_created_at: (startCreatedAt) OPTIONAL int in query

        status: (status) OPTIONAL Union[str, StatusEnum] in query

        transient: (transient) OPTIONAL bool in query

    Responses:
        200: OK - ModelsGetInboxMessagesResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetInboxMessages.create(
        active_only=active_only,
        end_created_at=end_created_at,
        limit=limit,
        message_id=message_id,
        offset=offset,
        order=order,
        scope=scope,
        start_created_at=start_created_at,
        status=status,
        transient=transient,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetInboxStats)
def admin_get_inbox_stats(
    message_id: Optional[List[str]] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get inbox stats (adminGetInboxStats)

    Get inbox stats

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/stats

        method: GET

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        message_id: (messageId) OPTIONAL List[str] in query

    Responses:
        200: OK - ModelsGetInboxStatsResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetInboxStats.create(
        message_id=message_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetInboxStats)
async def admin_get_inbox_stats_async(
    message_id: Optional[List[str]] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get inbox stats (adminGetInboxStats)

    Get inbox stats

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/stats

        method: GET

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        message_id: (messageId) OPTIONAL List[str] in query

    Responses:
        200: OK - ModelsGetInboxStatsResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetInboxStats.create(
        message_id=message_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetInboxUsers)
def admin_get_inbox_users(
    inbox: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    status: Optional[Union[str, AdminGetInboxUsersStatusEnum]] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get inbox users (adminGetInboxUsers)

    Get inbox users

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/messages/{inbox}/users

        method: GET

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        inbox: (inbox) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        status: (status) OPTIONAL Union[str, StatusEnum] in query

        user_id: (userId) OPTIONAL str in query

    Responses:
        200: OK - ModelsGetInboxUsersResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetInboxUsers.create(
        inbox=inbox,
        limit=limit,
        offset=offset,
        status=status,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetInboxUsers)
async def admin_get_inbox_users_async(
    inbox: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    status: Optional[Union[str, AdminGetInboxUsersStatusEnum]] = None,
    user_id: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get inbox users (adminGetInboxUsers)

    Get inbox users

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/messages/{inbox}/users

        method: GET

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        inbox: (inbox) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        status: (status) OPTIONAL Union[str, StatusEnum] in query

        user_id: (userId) OPTIONAL str in query

    Responses:
        200: OK - ModelsGetInboxUsersResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetInboxUsers.create(
        inbox=inbox,
        limit=limit,
        offset=offset,
        status=status,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminSaveInboxMessage)
def admin_save_inbox_message(
    body: ModelsSaveInboxMessageRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin save inbox message (adminSaveInboxMessage)

    Save inbox message

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/messages

        method: POST

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsSaveInboxMessageRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsSaveInboxMessageResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminSaveInboxMessage.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminSaveInboxMessage)
async def admin_save_inbox_message_async(
    body: ModelsSaveInboxMessageRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin save inbox message (adminSaveInboxMessage)

    Save inbox message

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/messages

        method: POST

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsSaveInboxMessageRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsSaveInboxMessageResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminSaveInboxMessage.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminSendInboxMessage)
def admin_send_inbox_message(
    body: ModelsSendInboxMessageRequest,
    message_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin send inbox message (adminSendInboxMessage)

    Send inbox message

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/messages/{messageId}/send

        method: POST

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsSendInboxMessageRequest in body

        message_id: (messageId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsSendInboxMessageResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminSendInboxMessage.create(
        body=body,
        message_id=message_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminSendInboxMessage)
async def admin_send_inbox_message_async(
    body: ModelsSendInboxMessageRequest,
    message_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin send inbox message (adminSendInboxMessage)

    Send inbox message

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/messages/{messageId}/send

        method: POST

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsSendInboxMessageRequest in body

        message_id: (messageId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsSendInboxMessageResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminSendInboxMessage.create(
        body=body,
        message_id=message_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminUnsendInboxMessage)
def admin_unsend_inbox_message(
    body: ModelsUnsendInboxMessageRequest,
    inbox: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin unsend inbox message (adminUnsendInboxMessage)

    Unsend inbox message

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/messages/{inbox}/unsend

        method: POST

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUnsendInboxMessageRequest in body

        inbox: (inbox) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsUnsendInboxMessageResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminUnsendInboxMessage.create(
        body=body,
        inbox=inbox,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminUnsendInboxMessage)
async def admin_unsend_inbox_message_async(
    body: ModelsUnsendInboxMessageRequest,
    inbox: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin unsend inbox message (adminUnsendInboxMessage)

    Unsend inbox message

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/messages/{inbox}/unsend

        method: POST

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUnsendInboxMessageRequest in body

        inbox: (inbox) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsUnsendInboxMessageResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminUnsendInboxMessage.create(
        body=body,
        inbox=inbox,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminUpdateInboxCategory)
def admin_update_inbox_category(
    body: ModelsUpdateInboxCategoryRequest,
    category: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin update inbox category (adminUpdateInboxCategory)

    Update inbox category

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/categories/{category}

        method: PATCH

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUpdateInboxCategoryRequest in body

        category: (category) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminUpdateInboxCategory.create(
        body=body,
        category=category,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminUpdateInboxCategory)
async def admin_update_inbox_category_async(
    body: ModelsUpdateInboxCategoryRequest,
    category: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin update inbox category (adminUpdateInboxCategory)

    Update inbox category

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/categories/{category}

        method: PATCH

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUpdateInboxCategoryRequest in body

        category: (category) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminUpdateInboxCategory.create(
        body=body,
        category=category,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminUpdateInboxMessage)
def admin_update_inbox_message(
    body: ModelsUpdateInboxMessageRequest,
    message_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin update inbox message (adminUpdateInboxMessage)

    Update inbox message

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/messages/{messageId}

        method: PATCH

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUpdateInboxMessageRequest in body

        message_id: (messageId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminUpdateInboxMessage.create(
        body=body,
        message_id=message_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminUpdateInboxMessage)
async def admin_update_inbox_message_async(
    body: ModelsUpdateInboxMessageRequest,
    message_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin update inbox message (adminUpdateInboxMessage)

    Update inbox message

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/messages/{messageId}

        method: PATCH

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUpdateInboxMessageRequest in body

        message_id: (messageId) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminUpdateInboxMessage.create(
        body=body,
        message_id=message_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

# AccelByte Gaming Services Chat Service

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Operation
from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import HttpResponse
from accelbyte_py_sdk.core import StrEnum

from ...models import ModelsGetInboxMessagesResponse
from ...models import RestapiErrorResponseBody


class ScopeEnum(StrEnum):
    NAMESPACE = "NAMESPACE"
    USER = "USER"


class StatusEnum(StrEnum):
    DRAFT = "DRAFT"
    SENT = "SENT"
    UNSENT = "UNSENT"


class AdminGetInboxMessages(Operation):
    """admin get inbox messages (adminGetInboxMessages)

    Get inbox messages

    Properties:
        url: /chat/v1/admin/inbox/namespaces/{namespace}/messages

        method: GET

        tags: ["inbox"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        active_only: (activeOnly) OPTIONAL bool in query

        end_created_at: (endCreatedAt) OPTIONAL int in query

        limit: (limit) OPTIONAL int in query

        message_id: (messageId) OPTIONAL List[str] in query

        offset: (offset) OPTIONAL int in query

        order: (order) OPTIONAL str in query

        scope: (scope) OPTIONAL Union[str, ScopeEnum] in query

        start_created_at: (startCreatedAt) OPTIONAL int in query

        status: (status) OPTIONAL Union[str, StatusEnum] in query

        transient: (transient) OPTIONAL bool in query

    Responses:
        200: OK - ModelsGetInboxMessagesResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)
    """

    # region fields

    _url: str = "/chat/v1/admin/inbox/namespaces/{namespace}/messages"
    _path: str = "/chat/v1/admin/inbox/namespaces/{namespace}/messages"
    _base_path: str = ""
    _method: str = "GET"
    _consumes: List[str] = ["application/json"]
    _produces: List[str] = ["application/json"]
    _securities: List[List[str]] = [["BEARER_AUTH"]]
    _location_query: str = None

    service_name: Optional[str] = "chat"

    namespace: str  # REQUIRED in [path]
    active_only: bool  # OPTIONAL in [query]
    end_created_at: int  # OPTIONAL in [query]
    limit: int  # OPTIONAL in [query]
    message_id: List[str]  # OPTIONAL in [query]
    offset: int  # OPTIONAL in [query]
    order: str  # OPTIONAL in [query]
    scope: Union[str, ScopeEnum]  # OPTIONAL in [query]
    start_created_at: int  # OPTIONAL in [query]
    status: Union[str, StatusEnum]  # OPTIONAL in [query]
    transient: bool  # OPTIONAL in [query]

    # endregion fields

    # region properties

    @property
    def url(self) -> str:
        return self._url

    @property
    def path(self) -> str:
        return self._path

    @property
    def base_path(self) -> str:
        return self._base_path

    @property
    def method(self) -> str:
        return self._method

    @property
    def consumes(self) -> List[str]:
        return self._consumes

    @property
    def produces(self) -> List[str]:
        return self._produces

    @property
    def securities(self) -> List[List[str]]:
        return self._securities

    @property
    def location_query(self) -> str:
        return self._location_query

    # endregion properties

    # region get methods

    # endregion get methods

    # region get_x_params methods

    def get_all_params(self) -> dict:
        return {
            "path": self.get_path_params(),
            "query": self.get_query_params(),
        }

    def get_path_params(self) -> dict:
        result = {}
        if hasattr(self, "namespace"):
            result["namespace"] = self.namespace
        return result

    def get_query_params(self) -> dict:
        result = {}
        if hasattr(self, "active_only"):
            result["activeOnly"] = self.active_only
        if hasattr(self, "end_created_at"):
            result["endCreatedAt"] = self.end_created_at
        if hasattr(self, "limit"):
            result["limit"] = self.limit
        if hasattr(self, "message_id"):
            result["messageId"] = self.message_id
        if hasattr(self, "offset"):
            result["offset"] = self.offset
        if hasattr(self, "order"):
            result["order"] = self.order
        if hasattr(self, "scope"):
            result["scope"] = self.scope
        if hasattr(self, "start_created_at"):
            result["startCreatedAt"] = self.start_created_at
        if hasattr(self, "status"):
            result["status"] = self.status
        if hasattr(self, "transient"):
            result["transient"] = self.transient
        return result

    # endregion get_x_params methods

    # region is/has methods

    # endregion is/has methods

    # region with_x methods

    def with_namespace(self, value: str) -> AdminGetInboxMessages:
        self.namespace = value
        return self

    def with_active_only(self, value: bool) -> AdminGetInboxMessages:
        self.active_only = value
        return self

    def with_end_created_at(self, value: int) -> AdminGetInboxMessages:
        self.end_created_at = value
        return self

    def with_limit(self, value: int) -> AdminGetInboxMessages:
        self.limit = value
        return self

    def with_message_id(self, value: List[str]) -> AdminGetInboxMessages:
        self.message_id = value
        return self

    def with_offset(self, value: int) -> AdminGetInboxMessages:
        self.offset = value
        return self

    def with_order(self, value: str) -> AdminGetInboxMessages:
        self.order = value
        return self

    def with_scope(self, value: Union[str, ScopeEnum]) -> AdminGetInboxMessages:
        self.scope = value
        return self

    def with_start_created_at(self, value: int) -> AdminGetInboxMessages:
        self.start_created_at = value
        return self

    def with_status(self, value: Union[str, StatusEnum]) -> AdminGetInboxMessages:
        self.status = value
        return self

    def with_transient(self, value: bool) -> AdminGetInboxMessages:
        self.transient = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "namespace") and self.namespace:
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "active_only") and self.active_only:
            result["activeOnly"] = bool(self.active_only)
        elif include_empty:
            result["activeOnly"] = False
        if hasattr(self, "end_created_at") and self.end_created_at:
            result["endCreatedAt"] = int(self.end_created_at)
        elif include_empty:
            result["endCreatedAt"] = 0
        if hasattr(self, "limit") and self.limit:
            result["limit"] = int(self.limit)
        elif include_empty:
            result["limit"] = 0
        if hasattr(self, "message_id") and self.message_id:
            result["messageId"] = [str(i0) for i0 in self.message_id]
        elif include_empty:
            result["messageId"] = []
        if hasattr(self, "offset") and self.offset:
            result["offset"] = int(self.offset)
        elif include_empty:
            result["offset"] = 0
        if hasattr(self, "order") and self.order:
            result["order"] = str(self.order)
        elif include_empty:
            result["order"] = ""
        if hasattr(self, "scope") and self.scope:
            result["scope"] = str(self.scope)
        elif include_empty:
            result["scope"] = Union[str, ScopeEnum]()
        if hasattr(self, "start_created_at") and self.start_created_at:
            result["startCreatedAt"] = int(self.start_created_at)
        elif include_empty:
            result["startCreatedAt"] = 0
        if hasattr(self, "status") and self.status:
            result["status"] = str(self.status)
        elif include_empty:
            result["status"] = Union[str, StatusEnum]()
        if hasattr(self, "transient") and self.transient:
            result["transient"] = bool(self.transient)
        elif include_empty:
            result["transient"] = False
        return result

    # endregion to methods

    # region response methods

    # noinspection PyMethodMayBeStatic
    def parse_response(
        self, code: int, content_type: str, content: Any
    ) -> Tuple[
        Union[None, ModelsGetInboxMessagesResponse],
        Union[None, HttpResponse, RestapiErrorResponseBody],
    ]:
        """Parse the given response.

        200: OK - ModelsGetInboxMessagesResponse (OK)

        400: Bad Request - RestapiErrorResponseBody (Bad Request)

        401: Unauthorized - RestapiErrorResponseBody (Unauthorized)

        403: Forbidden - RestapiErrorResponseBody (Forbidden)

        500: Internal Server Error - RestapiErrorResponseBody (Internal Server Error)

        ---: HttpResponse (Undocumented Response)

        ---: HttpResponse (Unexpected Content-Type Error)

        ---: HttpResponse (Unhandled Error)
        """
        pre_processed_response, error = self.pre_process_response(
            code=code, content_type=content_type, content=content
        )
        if error is not None:
            return None, None if error.is_no_content() else error
        code, content_type, content = pre_processed_response

        if code == 200:
            return ModelsGetInboxMessagesResponse.create_from_dict(content), None
        if code == 400:
            return None, RestapiErrorResponseBody.create_from_dict(content)
        if code == 401:
            return None, RestapiErrorResponseBody.create_from_dict(content)
        if code == 403:
            return None, RestapiErrorResponseBody.create_from_dict(content)
        if code == 500:
            return None, RestapiErrorResponseBody.create_from_dict(content)

        return self.handle_undocumented_response(
            code=code, content_type=content_type, content=content
        )

    # endregion response methods

    # region static methods

    @classmethod
    def create(
        cls,
        namespace: str,
        active_only: Optional[bool] = None,
        end_created_at: Optional[int] = None,
        limit: Optional[int] = None,
        message_id: Optional[List[str]] = None,
        offset: Optional[int] = None,
        order: Optional[str] = None,
        scope: Optional[Union[str, ScopeEnum]] = None,
        start_created_at: Optional[int] = None,
        status: Optional[Union[str, StatusEnum]] = None,
        transient: Optional[bool] = None,
        **kwargs,
    ) -> AdminGetInboxMessages:
        instance = cls()
        instance.namespace = namespace
        if active_only is not None:
            instance.active_only = active_only
        if end_created_at is not None:
            instance.end_created_at = end_created_at
        if limit is not None:
            instance.limit = limit
        if message_id is not None:
            instance.message_id = message_id
        if offset is not None:
            instance.offset = offset
        if order is not None:
            instance.order = order
        if scope is not None:
            instance.scope = scope
        if start_created_at is not None:
            instance.start_created_at = start_created_at
        if status is not None:
            instance.status = status
        if transient is not None:
            instance.transient = transient
        if x_flight_id := kwargs.get("x_flight_id", None):
            instance.x_flight_id = x_flight_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> AdminGetInboxMessages:
        instance = cls()
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "activeOnly" in dict_ and dict_["activeOnly"] is not None:
            instance.active_only = bool(dict_["activeOnly"])
        elif include_empty:
            instance.active_only = False
        if "endCreatedAt" in dict_ and dict_["endCreatedAt"] is not None:
            instance.end_created_at = int(dict_["endCreatedAt"])
        elif include_empty:
            instance.end_created_at = 0
        if "limit" in dict_ and dict_["limit"] is not None:
            instance.limit = int(dict_["limit"])
        elif include_empty:
            instance.limit = 0
        if "messageId" in dict_ and dict_["messageId"] is not None:
            instance.message_id = [str(i0) for i0 in dict_["messageId"]]
        elif include_empty:
            instance.message_id = []
        if "offset" in dict_ and dict_["offset"] is not None:
            instance.offset = int(dict_["offset"])
        elif include_empty:
            instance.offset = 0
        if "order" in dict_ and dict_["order"] is not None:
            instance.order = str(dict_["order"])
        elif include_empty:
            instance.order = ""
        if "scope" in dict_ and dict_["scope"] is not None:
            instance.scope = str(dict_["scope"])
        elif include_empty:
            instance.scope = Union[str, ScopeEnum]()
        if "startCreatedAt" in dict_ and dict_["startCreatedAt"] is not None:
            instance.start_created_at = int(dict_["startCreatedAt"])
        elif include_empty:
            instance.start_created_at = 0
        if "status" in dict_ and dict_["status"] is not None:
            instance.status = str(dict_["status"])
        elif include_empty:
            instance.status = Union[str, StatusEnum]()
        if "transient" in dict_ and dict_["transient"] is not None:
            instance.transient = bool(dict_["transient"])
        elif include_empty:
            instance.transient = False
        return instance

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "namespace": "namespace",
            "activeOnly": "active_only",
            "endCreatedAt": "end_created_at",
            "limit": "limit",
            "messageId": "message_id",
            "offset": "offset",
            "order": "order",
            "scope": "scope",
            "startCreatedAt": "start_created_at",
            "status": "status",
            "transient": "transient",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "namespace": True,
            "activeOnly": False,
            "endCreatedAt": False,
            "limit": False,
            "messageId": False,
            "offset": False,
            "order": False,
            "scope": False,
            "startCreatedAt": False,
            "status": False,
            "transient": False,
        }

    @staticmethod
    def get_collection_format_map() -> Dict[str, Union[None, str]]:
        return {
            "messageId": "multi",  # in query
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "scope": ["NAMESPACE", "USER"],  # in query
            "status": ["DRAFT", "SENT", "UNSENT"],  # in query
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Chat Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ModelsChatMessageResponse(Model):
    """Models chat message response (models.ChatMessageResponse)

    Properties:
        from_: (from) REQUIRED str

        id_: (id) REQUIRED str

        message: (message) REQUIRED str

        topic_id: (topicId) REQUIRED str

        read_at: (readAt) OPTIONAL int

        received_at: (receivedAt) OPTIONAL int
    """

    # region fields

    from_: str  # REQUIRED
    id_: str  # REQUIRED
    message: str  # REQUIRED
    topic_id: str  # REQUIRED
    read_at: int  # OPTIONAL
    received_at: int  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_from(self, value: str) -> ModelsChatMessageResponse:
        self.from_ = value
        return self

    def with_id(self, value: str) -> ModelsChatMessageResponse:
        self.id_ = value
        return self

    def with_message(self, value: str) -> ModelsChatMessageResponse:
        self.message = value
        return self

    def with_topic_id(self, value: str) -> ModelsChatMessageResponse:
        self.topic_id = value
        return self

    def with_read_at(self, value: int) -> ModelsChatMessageResponse:
        self.read_at = value
        return self

    def with_received_at(self, value: int) -> ModelsChatMessageResponse:
        self.received_at = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "from_"):
            result["from"] = str(self.from_)
        elif include_empty:
            result["from"] = ""
        if hasattr(self, "id_"):
            result["id"] = str(self.id_)
        elif include_empty:
            result["id"] = ""
        if hasattr(self, "message"):
            result["message"] = str(self.message)
        elif include_empty:
            result["message"] = ""
        if hasattr(self, "topic_id"):
            result["topicId"] = str(self.topic_id)
        elif include_empty:
            result["topicId"] = ""
        if hasattr(self, "read_at"):
            result["readAt"] = int(self.read_at)
        elif include_empty:
            result["readAt"] = 0
        if hasattr(self, "received_at"):
            result["receivedAt"] = int(self.received_at)
        elif include_empty:
            result["receivedAt"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        from_: str,
        id_: str,
        message: str,
        topic_id: str,
        read_at: Optional[int] = None,
        received_at: Optional[int] = None,
        **kwargs,
    ) -> ModelsChatMessageResponse:
        instance = cls()
        instance.from_ = from_
        instance.id_ = id_
        instance.message = message
        instance.topic_id = topic_id
        if read_at is not None:
            instance.read_at = read_at
        if received_at is not None:
            instance.received_at = received_at
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsChatMessageResponse:
        instance = cls()
        if not dict_:
            return instance
        if "from" in dict_ and dict_["from"] is not None:
            instance.from_ = str(dict_["from"])
        elif include_empty:
            instance.from_ = ""
        if "id" in dict_ and dict_["id"] is not None:
            instance.id_ = str(dict_["id"])
        elif include_empty:
            instance.id_ = ""
        if "message" in dict_ and dict_["message"] is not None:
            instance.message = str(dict_["message"])
        elif include_empty:
            instance.message = ""
        if "topicId" in dict_ and dict_["topicId"] is not None:
            instance.topic_id = str(dict_["topicId"])
        elif include_empty:
            instance.topic_id = ""
        if "readAt" in dict_ and dict_["readAt"] is not None:
            instance.read_at = int(dict_["readAt"])
        elif include_empty:
            instance.read_at = 0
        if "receivedAt" in dict_ and dict_["receivedAt"] is not None:
            instance.received_at = int(dict_["receivedAt"])
        elif include_empty:
            instance.received_at = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsChatMessageResponse]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsChatMessageResponse]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsChatMessageResponse,
        List[ModelsChatMessageResponse],
        Dict[Any, ModelsChatMessageResponse],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "from": "from_",
            "id": "id_",
            "message": "message",
            "topicId": "topic_id",
            "readAt": "read_at",
            "receivedAt": "received_at",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "from": True,
            "id": True,
            "message": True,
            "topicId": True,
            "readAt": False,
            "receivedAt": False,
        }

    # endregion static methods
